@@ -1,4 +1,4 @@
-# Copyrights 2001-2020 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package Mail::Transport::Mailx;
 use vars '$VERSION';
-$VERSION = '3.005';
+$VERSION = '3.006';
 
 use base 'Mail::Transport::Send';
 
@@ -20,28 +20,20 @@ use Carp;
 
 sub init($)
 {   my ($self, $args) = @_;
-
     $args->{via} = 'mailx';
 
     $self->SUPER::init($args) or return;
 
-    $self->{MTM_program}
-      = $args->{proxy}
+    $self->{MTM_program} = $args->{proxy}
      || $self->findBinary('mailx')
      || $self->findBinary('Mail')
      || $self->findBinary('mail')
      || return;
 
-    $self->{MTM_style}
-      = defined $args->{style}                       ? $args->{style}
-      : $^O =~ m/linux|freebsd|bsdos|netbsd|openbsd/ ? 'BSD'
-      :                                                'RFC822';
-
+    $self->{MTM_style} = $args->{style} // ( $^O =~ m/linux|freebsd|bsdos|netbsd|openbsd/ ? 'BSD' : 'RFC822' );
     $self;
 }
 
-#------------------------------------------
-
 
 sub _try_send_bsdish($$)
 {   my ($self, $message, $args) = @_;
@@ -49,33 +41,31 @@ sub _try_send_bsdish($$)
     my @options = ('-s' => $message->subject);
 
     {   local $" = ',';
-        my @cc  = map {$_->format} $message->cc;
+        my @cc  = map $_->format, $message->cc;
         push @options, ('-c' => "@cc")  if @cc;
 
-        my @bcc = map {$_->format} $message->bcc;
+        my @bcc = map $_->format, $message->bcc;
         push @options, ('-b' => "@bcc") if @bcc;
     }
 
-    my @to      = map {$_->format} $message->to;
+    my @to      = map $_->format, $message->to;
     my $program = $self->{MTM_program};
 
-    if((open MAILER, '|-')==0)
+    my $mailer;
+    if((open $mailer, '|-')==0)
     {   close STDOUT;
         { exec $program, @options, @to }
         $self->log(NOTICE => "Cannot start contact to $program: $!");
         exit 1;
     }
  
-    $self->putContent($message, \*MAILER, body_only => 1);
+    $self->putContent($message, $mailer, body_only => 1);
+
+    $mailer->close
+        or $self->log(ERROR => "Sending via mailx mailer $program failed: $! ($?)"), return 0;
 
     my $msgid = $message->messageId;
-
-    if(close MAILER) { $self->log(PROGRESS => "Message $msgid send.") }
-    else
-    {   $self->log(ERROR => "Sending via mailx mailer $program failed: $! ($?)");
-        return 0;
-    }
-
+    $self->log(PROGRESS => "Message $msgid send.");
     1;
 }
 
@@ -86,21 +76,15 @@ sub trySend($@)
         if $self->{MTM_style} eq 'BSD';
 
     my $program = $self->{MTM_program};
-    unless(open MAILER, '|-', $program, '-t')
-    {   $self->log(NOTICE => "Cannot start contact to $program: $!");
-        return 0;
-    }
+    open my $mailer, '|-', $program, '-t'
+        or $self->log(NOTICE => "Cannot start contact to $program: $!"), return 0;
  
-    $self->putContent($message, \*MAILER);
+    $self->putContent($message, $mailer);
 
-    unless(close MAILER)
-    {   $self->log(ERROR => "Sending via mailx mailer $program failed: $! ($?)");
-        return 0;
-    }
+    $mailer->close
+        or $self->log(ERROR => "Sending via mailx mailer $program failed: $! ($?)"), return 0;
 
     1;
 }
 
-#------------------------------------------
-
 1;
