@@ -1,16 +1,20 @@
-# Copyrights 2001-2017 by [Mark Overmeer].
+# Copyrights 2001-2025 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use strict;
-use warnings;
+# This code is part of distribution Mail-Transport.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package Mail::Transport::Send;
 use vars '$VERSION';
-$VERSION = '3.001';
+$VERSION = '3.006';
 
 use base 'Mail::Transport';
 
+use strict;
+use warnings;
+
 use Carp;
 use File::Spec;
 use Errno 'EAGAIN';
@@ -27,18 +31,20 @@ sub new(@)
 
 #------------------------------------------
 
-
 sub send($@)
 {   my ($self, $message, %args) = @_;
 
     unless($message->isa('Mail::Message'))  # avoid rebless.
     {   $message = Mail::Message->coerce($message);
-        confess "Unable to coerce object into Mail::Message."
-            unless defined $message;
+        defined $message
+            or confess "Unable to coerce object into Mail::Message.";
     }
 
-    return 1 if $self->trySend($message, %args);
-    return 0 unless $?==EAGAIN;
+    $self->trySend($message, %args)
+        and return 1;
+
+    $?==EAGAIN
+        or return 0;
 
     my ($interval, $retry) = $self->retry;
     $interval = $args{interval} if exists $args{interval};
@@ -47,23 +53,19 @@ sub send($@)
     while($retry!=0)
     {   sleep $interval;
         return 1 if $self->trySend($message, %args);
-        return 0 unless $?==EAGAIN;
+        $?==EAGAIN or return 0;
         $retry--;
     }
 
     0;
 }
 
-#------------------------------------------
-
 
 sub trySend($@)
 {   my $self = shift;
     $self->log(ERROR => "Transporters of type ".ref($self). " cannot send.");
 }
 
-#------------------------------------------
-
 
 sub putContent($$@)
 {   my ($self, $message, $fh, %args) = @_;
@@ -78,7 +80,6 @@ sub putContent($$@)
     $self;
 }
 
-#------------------------------------------
 
 
 sub destinations($;$)
@@ -86,19 +87,17 @@ sub destinations($;$)
     my @to;
 
     if(defined $overrule)      # Destinations overruled by user.
-    {   my @addr = ref $overrule eq 'ARRAY' ? @$overrule : ($overrule);
-        @to = map { ref $_ && $_->isa('Mail::Address') ? ($_)
-                    : Mail::Address->parse($_) } @addr;
+    {   @to = map { ref $_ && $_->isa('Mail::Address') ? ($_) : Mail::Address->parse($_) }
+            ref $overrule eq 'ARRAY' ? @$overrule : ($overrule);
     }
     elsif(my @rgs = $message->head->resentGroups)
-    {   @to = $rgs[0]->destinations;
-        $self->log(WARNING => "Resent group does not specify a destination"), return ()
-            unless @to;
+    {   # Create with bounce
+        @to = $rgs[0]->destinations;
+        @to or $self->log(WARNING => "Resent group does not specify a destination"), return ();
     }
     else
     {   @to = $message->destinations;
-        $self->log(WARNING => "Message has no destination"), return ()
-            unless @to;
+        @to or $self->log(WARNING => "Message has no destination"), return ();
     }
 
     @to;
@@ -106,5 +105,4 @@ sub destinations($;$)
 
 #------------------------------------------
 
-
 1;
